<?php
// Matikan semua output buffering yang ada
while (ob_get_level()) {
    ob_end_clean();
}

// Mulai buffer baru
ob_start();

// Nonaktifkan error reporting
error_reporting(0);
ini_set('display_errors', 0);

require_once 'includes/config.php';

try {
    // Get latest audio URLs for each type
    $stmt = $db->prepare("
        SELECT a1.type, a1.file_path 
        FROM audio_settings a1
        INNER JOIN (
            SELECT type, MAX(id) as max_id 
            FROM audio_settings 
            GROUP BY type
        ) a2 ON a1.type = a2.type AND a1.id = a2.max_id
    ");
    $stmt->execute();
    $audioFiles = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);
    
    // Debug log untuk melihat hasil query
    error_log("Audio files found: " . print_r($audioFiles, true));
    
    $audioUrls = [];
    foreach ($audioFiles as $type => $path) {
        $fullPath = AUDIO_UPLOAD_PATH . $path;
        // Debug log untuk path file
        error_log("Checking file: " . $fullPath);
        
        if (file_exists($fullPath)) {
            $audioUrls[$type] = BASE_URL . '/uploads/audio/' . $path;
            error_log("Audio URL for $type: " . $audioUrls[$type]);
        } else {
            error_log("File not found: " . $fullPath);
        }
    }

    // Debug log untuk audio URLs
    error_log("Final audio URLs: " . print_r($audioUrls, true));

    // Get input parameters
    $digits = isset($_POST['Digits']) ? $_POST['Digits'] : null;
    $to = isset($_POST['To']) ? $_POST['To'] : null;

    error_log("Received digits: " . ($digits === null ? 'null' : $digits));

    // Create TwiML response
    $response = new Twilio\TwiML\VoiceResponse();

    if ($digits === null) {
        if (!isset($audioUrls['welcome'])) {
            error_log("Welcome audio not found in URLs");
            throw new Exception('Welcome audio not found');
        }
        $gather = $response->gather(['numDigits' => 1, 'timeout' => 10, 'action' => WEBHOOK_URL]);
        $gather->play($audioUrls['welcome']);
        error_log("Playing welcome audio: " . $audioUrls['welcome']);
    } 
    else if ($digits === '1') {
        if (!isset($audioUrls['confirmation'])) {
            error_log("Confirmation audio not found in URLs");
            throw new Exception('Confirmation audio not found');
        }
        $response->play($audioUrls['confirmation']);
        error_log("Playing confirmation audio: " . $audioUrls['confirmation']);
        
        if ($to) {
            $stmt = $db->prepare("UPDATE target_numbers SET status = 'Success', pressed_button = '1', call_date = NOW() WHERE phone_number = ?");
            $stmt->execute([$to]);
        }
    } 
    else {
        if (!isset($audioUrls['error'])) {
            error_log("Error audio not found in URLs");
            throw new Exception('Error audio not found');
        }
        $response->play($audioUrls['error']);
        error_log("Playing error audio: " . $audioUrls['error']);
        
        if ($to) {
            $stmt = $db->prepare("UPDATE target_numbers SET status = '-', pressed_button = ?, call_date = NOW() WHERE phone_number = ?");
            $stmt->execute([$digits, $to]);
        }
    }

    // Bersihkan semua output yang ada
    ob_clean();
    
    // Set header content type
    header('Content-Type: text/xml');
    
    // Keluarkan XML response
    $xml = $response->asXML();
    // Pastikan tidak ada BOM atau whitespace
    $xml = preg_replace('/^\xEF\xBB\xBF/', '', $xml);
    $xml = preg_replace('/^\s+/', '', $xml);
    error_log("Sending XML response: " . $xml);
    echo $xml;
    
} catch (Exception $e) {
    error_log("Webhook error: " . $e->getMessage());
    error_log("Stack trace: " . $e->getTraceAsString());
    
    // Bersihkan output
    ob_clean();
    
    // Set header
    header('Content-Type: text/xml');
    
    // Buat response error
    $response = new Twilio\TwiML\VoiceResponse();
    $response->say('Maaf, terjadi kesalahan sistem.', ['language' => 'id-ID']);
    echo $response->asXML();
}
// Flush dan hentikan output buffering
ob_end_flush();
